@@ -17,7 +17,6 @@ from wtforms_components import (
 )
 from .utils import (
     is_date_column,
-    is_integer_column,
     is_scalar,
     null_or_int,
     null_or_unicode,
@@ -45,14 +44,13 @@ __all__ = (
     Unique,
     UnknownTypeException,
     is_date_column,
-    is_integer_column,
     is_scalar,
     null_or_int,
     null_or_unicode,
 )
 
 
-__version__ = '0.12.1'
+__version__ = '0.12.2'
 
 
 class ModelFormMeta(FormMeta):
@@ -196,6 +194,10 @@ def model_form_factory(base=Form, meta=ModelFormMeta, **defaults):
             #: type conversion in class level.
             type_map = defaults.pop('type_map', ClassMap())
 
+            #: Whether or not to raise InvalidAttributExceptions when invalid
+            #: attribute names are given for include / exclude or only
+            attr_errors = defaults.pop('attr_errors', True)
+
             #: Additional fields to include in the generated form.
             include = defaults.pop('include', [])
 
