@@ -54,7 +54,8 @@ from .exc import (
 from .utils import (
     flatten,
     is_date_column,
-    is_integer_column,
+    is_number,
+    is_number_range,
     is_scalar,
     null_or_unicode,
     strip_string,
@@ -158,6 +159,7 @@ class FormGenerator(object):
             attrs = OrderedDict([
                 (key, prop)
                 for key, prop in map(self.validate_attribute, self.meta.only)
+                if key
             ])
         else:
             if self.meta.include:
@@ -165,11 +167,16 @@ class FormGenerator(object):
                     (key, prop)
                     for key, prop
                     in map(self.validate_attribute, self.meta.include)
+                    if key
                 ])
 
             if self.meta.exclude:
                 for key in self.meta.exclude:
-                    del attrs[key]
+                    try:
+                        del attrs[key]
+                    except KeyError:
+                        if self.meta.attr_errors:
+                            raise InvalidAttributeException(key)
         return attrs
 
     def validate_attribute(self, attr_name):
@@ -188,11 +195,16 @@ class FormGenerator(object):
                 )
                 attr = getattr(translation_class, attr_name)
             except AttributeError:
-                raise InvalidAttributeException(attr_name)
-
+                if self.meta.attr_errors:
+                    raise InvalidAttributeException(attr_name)
+                else:
+                    return None, None
         try:
             if not isinstance(attr.property, ColumnProperty):
-                raise InvalidAttributeException(attr_name)
+                if self.meta.attr_errors:
+                    raise InvalidAttributeException(attr_name)
+                else:
+                    return None, None
         except AttributeError:
             raise AttributeTypeException(attr_name)
         return attr_name, attr.property
@@ -544,7 +556,7 @@ class FormGenerator(object):
         max_ = column.info.get('max')
 
         if min_ is not None or max_ is not None:
-            if is_integer_column(column):
+            if is_number(column.type) or is_number_range(column.type):
                 return self.get_validator('number_range', min=min_, max=max_)
             elif is_date_column(column):
                 return self.get_validator('date_range', min=min_, max=max_)
